==> avassa-client-0.1.6.crate: avassa-client-0.1.6/src/utilities/mod.rs <==
//!
//! Optional utility functions
//!

pub mod application_metrics;
pub mod types;

/// State utility functions
pub mod state {
    use super::types;
    use crate::Client;

    /// Returns a list of DCs a tenant can access
    pub async fn assigned_sites(client: &Client) -> crate::Result<Vec<types::state::site::Site>> {
        let sites = client.get_json("/v1/state/assigned-sites", None).await?;
        Ok(sites)
    }

    /// Return the site name
    pub async fn site_name(client: &Client) -> crate::Result<String> {
        client
            .get_json::<serde_json::Value>("/v1/state/cluster", None)
            .await?
            .as_object()
            .ok_or_else(|| crate::Error::general("Failed to get cluster information"))?
            .get("cluster-id")
            .map(serde_json::Value::as_str)
            .flatten()
            .ok_or_else(|| crate::Error::general("Failed to get cluster_id"))
            .map(Into::into)
    }

    /// Return an applications service instance state
    pub async fn service_instance(
        client: &Client,
        application: &str,
        service_instance: &str,
    ) -> crate::Result<types::state::application::ServiceInstance> {
        let si = client
            .get_json(
                &format!(
                    "/v1/state/applications/{}/service-instances/{}",
                    application, service_instance
                ),
                None,
            )
            .await?;

        Ok(si)
    }

    /// Return an applications service instances state
    pub async fn service_instances(
        client: &Client,
        application: &str,
    ) -> crate::Result<Vec<types::state::application::ServiceInstance>> {
        let si = client
            .get_json(
                &format!("/v1/state/applications/{}/service-instances", application),
                None,
            )
            .await?;

        Ok(si)
    }
}

==> avassa-client-0.2.1.crate: avassa-client-0.2.1/src/utilities/mod.rs <==
//!
//! Optional utility functions
//!

pub mod application_metrics;
pub mod types;

/// State utility functions
pub mod state {
    use super::types;
    use crate::Client;

    /// Returns a list of DCs a tenant can access
    pub async fn assigned_sites(client: &Client) -> crate::Result<Vec<types::state::site::Site>> {
        let sites = client.get_json("/v1/state/assigned-sites", None).await?;
        Ok(sites)
    }

    /// Return the site name
    pub async fn site_name(client: &Client) -> crate::Result<String> {
        client
            .get_json::<serde_json::Value>("/v1/state/system/cluster", None)
            .await?
            .as_object()
            .ok_or_else(|| crate::Error::general("Failed to get cluster information"))?
            .get("site-name")
            .and_then(serde_json::Value::as_str)
            .ok_or_else(|| crate::Error::general("Failed to get site name"))
            .map(Into::into)
    }

    /// Return an applications service instance state
    pub async fn service_instance(
        client: &Client,
        application: &str,
        service_instance: &str,
    ) -> crate::Result<types::state::application::ServiceInstance> {
        let si = client
            .get_json(
                &format!(
                    "/v1/state/applications/{}/service-instances/{}",
                    application, service_instance
                ),
                None,
            )
            .await?;

        Ok(si)
    }

    /// Return an applications service instances state
    pub async fn service_instances(
        client: &Client,
        application: &str,
    ) -> crate::Result<Vec<types::state::application::ServiceInstance>> {
        let si = client
            .get_json(
                &format!("/v1/state/applications/{}/service-instances", application),
                None,
            )
            .await?;

        Ok(si)
    }
}
